@@ -15,7 +15,7 @@ with 'WWW::FBX::Role::Auth';
  
 use namespace::autoclean;
 
-our $VERSION="0.05";
+our $VERSION="0.06";
 
 has lwp_args    => ( isa => 'HashRef', is => 'ro', default => sub { {} } );
 has ua          => ( isa => 'LWP::UserAgent', is => 'rw', lazy => 1, builder => '_build_ua' );
@@ -105,9 +105,13 @@ sub _parse_result {
         die WWW::FBX::Error->new(fbx_error => $j_obj, http_response => $res);
     }
 
-    #If no API error and HTTP is 200
+    #If no API error and HTTP is 200 and answer is json
     return $j_obj if $res->is_success && defined $j_obj;
 
+    #API Download file does not return JSON!!
+    #If answer is 200 and not json, return unchanged (but still pack it in an HashRef for uar type check..)
+    return {content => $content} if $res->is_success;
+
     #Else die on HTTP failures, which might contain a json response or not
     my $error = WWW::FBX::Error->new(http_response => $res);
     $error->fbx_error($j_obj) if ref $j_obj;
