@@ -2,6 +2,7 @@ package WWW::FBX::Role::API::APIv3;
 use 5.008001;
 use Moose::Role;
 use WWW::FBX::API;
+use MIME::Base64 qw/encode_base64 decode_base64/;
 
 #sub BUILD {
 #  shift->api_version;
@@ -164,30 +165,215 @@ Add a feed.
   params => [ qw/url/ ],
   required => [ qw/url/ ],
 );
-#TODO the rest..
+
+fbx_api_method del_feed => (
+  description => <<'',
+Delete download feed.
+
+  path => "downloads/feeds/",
+  method => 'DELETE',
+  params => [ qw/suff/ ],
+  required => [ qw/suff/ ],
+);
+
+fbx_api_method upd_feed => (
+  description => <<'',
+Update download feed.
+
+  path => 'downloads/feeds/',
+  method => 'PUT',
+  params => [ qw/suff/ ],
+  required => [ qw/suff/ ],
+);
+
+fbx_api_method $_ => (
+  description => <<'',
+Global feed POST.
+
+  path => 'downloads/feeds/',
+  method => 'POST',
+  params => [ qw/suff/ ],
+  required => [ qw/suff/ ],
+) for qw/refresh_feed download_feed_item mark_all_read/;
+
+fbx_api_method refresh_feeds => (
+  description => <<'',
+Refresh all feeds.
+
+  path => 'downloads/feeds/fetch',
+  method => 'POST',
+  params => [ ],
+  required => [ ],
+);
 
 #Download config
-fbx_api_method s'/'_'gr => (
+fbx_api_method downloads_config => (
   description => <<'',
-Global download config getters.
+Get Downloads config.
 
-  path => $_,
+  path => "downloads/config",
   method => 'GET',
   params => [ ],
   required => [ ],
+);
+
+fbx_api_method upd_downloads_config => (
+  description => <<'',
+Update downloads config.
+
+  path => "downloads/config",
+  method => 'PUT',
+  params => [ qw/throttling max_downloading_tasks download_dir use_watch_dir watch_dir news bt feed/],
+  required => [ ],
 ) for qw(downloads/config/);
 
+around downloads_config => sub {
+  my $orig = shift;
+  my $self = shift;
+  
+  my $params = $self->$orig(@_);
+
+  for (qw/download_dir watch_dir/) { 
+    $params->{result}{$_} = decode_base64( $params->{result}{$_} ) if exists $params->{result}{$_} and $params->{result}{$_};
+  }
+
+  $params;
+};
+
+around upd_downloads_config => sub {
+  my $orig = shift;
+  my $self = shift;
+
+  if (@_) {
+    my $params = $_[0];
+    for my $par (qw/download_dir watch_dir/) { 
+      $params->{$par} = encode_base64( $params->{$par}, "") if exists $params->{$par} and $params->{$par};
+    }
+  }
+
+  $self->$orig(@_);
+};
+
+fbx_api_method upd_downloads_throttle => (
+  description => <<'',
+Update download throttling.
+
+  path => "downloads/throttling",
+  method => 'PUT',
+  params => [ qw/throttling/],
+  required => [ qw/throttling/ ],
+);
+
 #FS
 fbx_api_method s'/'_'gr => (
   description => <<'',
-Global fs getters.
+Get task(s).
 
   path => $_,
   method => 'GET',
-  params => [ ],
+  params => [ qw/suff/ ],
   required => [ ],
 ) for qw(fs/tasks/);
 
+fbx_api_method del_task => (
+  description => <<'',
+Delete task.
+
+  path => "fs/tasks/",
+  method => 'DELETE',
+  params => [ qw/suff/ ],
+  required => [ ],
+);
+
+fbx_api_method upd_task => (
+  description => <<'',
+Update task.
+
+  path => "fs/tasks/",
+  method => 'PUT',
+  params => [ qw/suff state/ ],
+  required => [ qw/suff state/ ],
+);
+
+fbx_api_method list_files => (
+  description => <<'',
+List files.
+
+  path => "fs/ls/",
+  method => 'GET',
+  params => [ qw/suff / ],
+  required => [ qw/suff/ ],
+);
+
+around list_files => sub {
+  my $orig = shift;
+  my $self = shift;
+
+  if (@_) {
+    my $params = $_[0];
+    $params->{suff} = encode_base64( $params->{suff}, "") if exists $params->{suff} and $params->{suff};
+  }
+
+  my $res = $self->$orig(@_);
+  for my $i ( 0.. $#{$res->{result}} ) {
+    $res->{result}->[$i]{path} = decode_base64( $res->{result}[$i]{path} ); 
+  }
+
+  $res;
+};
+
+fbx_api_method file_info => (
+  description => <<'',
+Get file information.
+
+  path => "fs/info/",
+  method => 'GET',
+  params => [ qw/suff/ ],
+  required => [ qw/suff/ ],
+);
+
+around file_info => sub {
+  my $orig = shift;
+  my $self = shift;
+  
+  if (@_) {
+    my $params = $_[0];
+    $params->{suff} = encode_base64( $params->{suff}, "") if exists $params->{suff} and $params->{suff};
+  }
+
+  my $params = $self->$orig(@_);
+
+  for (qw/parent target path/) { 
+    $params->{result}{$_} = decode_base64( $params->{result}{$_} ) if exists $params->{result}{$_} and $params->{result}{$_};
+  }
+
+  $params;
+};
+
+#TODO mv, cp, rm, cat, archive, extract, repair, hash, mkdir, rename
+
+fbx_api_method download_file => (
+  description => <<'',
+Download a file.
+
+  path => "dl/",
+  method => 'GET',
+  params => [ qw/suff/ ],
+  required => [ qw/suff/ ],
+);
+
+around download_file => sub {
+  my $orig = shift;
+  my $self = shift;
+  
+  if (@_) {
+    my $params = $_[0];
+    $params->{suff} = encode_base64( $params->{suff}, "") if exists $params->{suff} and $params->{suff};
+  }
+
+  $self->$orig(@_)->{content};
+};
+
 #Share
 fbx_api_method s'/'_'gr => (
   description => <<'',
@@ -521,6 +707,9 @@ WWW::FBX::Role::API::APIv3 is the freebox6 API version 3 as a Moose Role
 
 =head1 API
 
+API documentation is given here: L<http://dev.freebox.fr/sdk/os/>
+The following methods are currently implemented in this library:
+
 =head2 call
 
 =head3 call log
@@ -621,14 +810,58 @@ my $res = $res = $fbx->get_download_task( {suff => "76/peers"});
 
 my $res = $fbx->downloads_stats;
 
-=head3 downloads feeds
+=head3 download feeds
 
 my $res = $fbx->downloads_feeds;
 
+=head3 download feed
+
+my $res = $fbx->downloads_feeds( { suff => "1"};
+
+=head3 del feed
+
+my $res = $fbx->del_feed({suff => "1"});
+
+=head3 update feed
+
+my $res = $fbx->upd_feed({suff=>"1", auto_download=> \1});
+
+=head3 refresh feed
+
+my $res = $fbx->refresh_feed({suff=>"1/fetch"});
+
+=head3 refresh all feeds
+
+my $res = $fbx->refresh_feeds;
+
+=head3 download feed items
+
+my $res = $fbx->downloads_feeds({suff=>"1/items"};
+
+=head3 update a feed item
+
+my $res = $fbx->upd_feed({suff=>"1/items/6"};
+
+=head3 download a feed item
+
+my $res = $fbx->download_feed_item({suff=>"1/items/6/download"};
+
+=head3 mark all items as read
+
+my $res = $fbx->mark_all_read({suff=>"1/items/mark_all_as_read"};
+
 =head3 add feed
 
 my $res = $res = $fbx->add_feed({url=>"http://www.nzb-rss.com/rss/Debian-unstable.rss"});
 
+=head3 update downloads config
+
+my $res = $res = $fbx->upd_downloads_config({max_downloading_tasks => 6, download_dir=>"/Disque dur/Téléchargements/"});
+
+=head3 update throttling
+
+my $res = $res = $fbx->upd_downloads_throttle({throttling => "schedule"});
+
 =head3 downloads config
 
 my $res = $fbx->downloads_config;
@@ -645,6 +878,22 @@ my $res = $fbx->freeplugs_net;
 
 my $res = $fbx->fs_tasks;
 
+=head3 fs task
+
+my $res = $fbx->fs_tasks({suff=>"12"});
+
+=head3 fs task
+
+my $res = $fbx->upd_task({suff=>"12", state=>"paused"});
+
+=head3 list files
+
+my $res = $fbx->list_files({suff=>"/Disque dur/Photos/"});
+
+=head3 file info
+
+my $res = $res = $fbx->file_info({suff=>"Disque dur/Photos/Sydney/DSCF4323.JPG"});
+
 =head2 ftp
 
 =head3 ftp config
